from uuid import uuid1
import datetime


class Event:
    def __init__(self, paramenter: dict):
        self.event = dict()
        self.TIMEZONE = "Asia/Shanghai"
        self.event['DTSTART;TZID=' + self.TIMEZONE] = paramenter['DTSTART']
        self.event['DTEND;TZID=' + self.TIMEZONE] = paramenter['DTEND']
        self.event['DTSTAMP'] = datetime.datetime.now().strftime("%Y%m%dT%H%M%SZ")
        self.event['UID'] = str(uuid1())
        self.event['CREATED'] = datetime.datetime.now().strftime("%Y%m%dT%H%M%SZ")
        self.event['DESCRIPTION'] = paramenter['DESCRIPTION']
        self.event['LAST-MODIFIED'] = datetime.datetime.now().strftime("%Y%m%dT%H%M%SZ")
        self.event['STATUS'] = "CONFIRMED"
        self.event['SUMMARY'] = paramenter['SUMMARY']
        self.event['TRANSP'] = "OPAQUE"

    def __str__(self):
        return_string = str()

        return_string += "BEGIN:VEVENT\n"

        for key, value in self.event.items():
            return_string += key + ":" + value + "\n"

        return_string += "END:VEVENT\n"

        return return_string



import datetime
from Event import Event


def genEventsByWeeks(paramenter: dict, start_time: datetime, end_time:datetime , weeks: list):
    ret = list()
    for i in weeks:
        event_para = paramenter
        event_para["DTSTART"] = (start_time + datetime.timedelta(weeks=(i - 1))).strftime("%Y%m%dT%H%M%S")
        event_para["DTEND"] = (end_time + datetime.timedelta(weeks=(i - 1))).strftime("%Y%m%dT%H%M%S")
        event = Event(event_para)
        ret.append(event)

    return ret



class Calendar:
    cal = dict()
    events = list()

    def __init__(self):
        self.cal['PROID'] = "icshelper"
        self.cal['VERSION'] = "2.0"
        self.cal['CALSCALE'] = "GREGORIAN"
        self.cal['METHOD'] = "PUBLISH"
        self.cal['CLASS'] = "PUBLIC"

    def __str__(self):
        return_string = str()

        return_string += "BEGIN:VCALENDAR\n"

        for key, value in self.cal.items():
            return_string += key + ":" + value + "\n"

        for event in self.events:
            return_string += str(event)

        return_string += "END:VCALENDAR\n"

        return return_string

    def addEvents(self, events: list):
        self.events.extend(events)
